@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2021-2022 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2021-2023 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -160,7 +160,7 @@ rocsparse_importer_rocsparseio::rocsparse_importer_rocsparseio(const std::string
     istatus = rocsparseio_open(&this->m_handle, rocsparseio_rwmode_read, this->m_filename.c_str());
     if(istatus != rocsparseio_status_success)
     {
-        std::cerr << "Problem with closing rocsparseio_open" << std::endl;
+        std::cerr << "cannot open file '" << this->m_filename << "'" << std::endl;
         throw rocsparse_status_internal_error;
     }
 #else
