@@ -297,13 +297,7 @@ rocsparse_status rocsparse_bsr2csr_template(rocsparse_handle          handle,
     }
 
     // Check sizes
-    if(mb < 0 || nb < 0)
-    {
-        return rocsparse_status_invalid_size;
-    }
-
-    // Check block dimension
-    if(block_dim <= 0)
+    if(mb < 0 || nb < 0 || block_dim <= 0)
     {
         return rocsparse_status_invalid_size;
     }
@@ -311,6 +305,18 @@ rocsparse_status rocsparse_bsr2csr_template(rocsparse_handle          handle,
     // Quick return if possible
     if(mb == 0 || nb == 0)
     {
+        if(csr_row_ptr != nullptr)
+        {
+            rocsparse_int m = block_dim * mb;
+            hipLaunchKernelGGL((set_array_to_value<256>),
+                               dim3(((m + 1) - 1) / 256 + 1),
+                               dim3(256),
+                               0,
+                               handle->stream,
+                               (m + 1),
+                               csr_row_ptr,
+                               static_cast<rocsparse_int>(csr_descr->base));
+        }
         return rocsparse_status_success;
     }
 
@@ -334,25 +340,6 @@ rocsparse_status rocsparse_bsr2csr_template(rocsparse_handle          handle,
         return rocsparse_status_invalid_pointer;
     }
 
-    if(bsr_val == nullptr && bsr_col_ind == nullptr)
-    {
-        rocsparse_int start = 0;
-        rocsparse_int end   = 0;
-
-        RETURN_IF_HIP_ERROR(hipMemcpyAsync(
-            &end, &bsr_row_ptr[mb], sizeof(rocsparse_int), hipMemcpyDeviceToHost, handle->stream));
-        RETURN_IF_HIP_ERROR(hipMemcpyAsync(
-            &start, &bsr_row_ptr[0], sizeof(rocsparse_int), hipMemcpyDeviceToHost, handle->stream));
-        RETURN_IF_HIP_ERROR(hipStreamSynchronize(handle->stream));
-
-        rocsparse_int nnzb = (end - start);
-
-        if(nnzb != 0)
-        {
-            return rocsparse_status_invalid_pointer;
-        }
-    }
-
     // Check the description type of the matrix.
     if(rocsparse_matrix_type_general != bsr_descr->type
        || rocsparse_matrix_type_general != csr_descr->type)
