@@ -195,25 +195,16 @@ rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle
     {
         if(nnz_total_dev_host_ptr != nullptr && csr_row_ptr != nullptr)
         {
-            rocsparse_pointer_mode mode;
-            rocsparse_status       status = rocsparse_get_pointer_mode(handle, &mode);
-            if(rocsparse_status_success != status)
-            {
-                return status;
-            }
-
-            constexpr rocsparse_int block_size = 1024;
-            rocsparse_int           grid_size  = (m + block_size - 1) / block_size;
-            hipLaunchKernelGGL((fill_row_ptr_device<block_size>),
-                               dim3(grid_size),
-                               dim3(block_size),
+            hipLaunchKernelGGL((set_array_to_value<256>),
+                               dim3(m / 256 + 1),
+                               dim3(256),
                                0,
                                stream,
-                               m,
-                               descr->base,
-                               csr_row_ptr);
+                               (m + 1),
+                               csr_row_ptr,
+                               static_cast<rocsparse_int>(descr->base));
 
-            if(rocsparse_pointer_mode_device == mode)
+            if(handle->pointer_mode == rocsparse_pointer_mode_device)
             {
                 RETURN_IF_HIP_ERROR(hipMemsetAsync(
                     nnz_total_dev_host_ptr, 0, sizeof(rocsparse_int), handle->stream));
@@ -274,6 +265,7 @@ rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle
     rocsparse_int first_value = descr->base;
     RETURN_IF_HIP_ERROR(hipMemcpyAsync(
         csr_row_ptr, &first_value, sizeof(rocsparse_int), hipMemcpyHostToDevice, handle->stream));
+    RETURN_IF_HIP_ERROR(hipStreamSynchronize(handle->stream));
 
     // Obtain rocprim buffer size
     size_t temp_storage_bytes = 0;
@@ -310,6 +302,7 @@ rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle
                                                 m + 1,
                                                 rocprim::plus<rocsparse_int>(),
                                                 handle->stream));
+
     // Free rocprim buffer, if allocated
     if(d_temp_alloc == true)
     {
@@ -330,13 +323,14 @@ rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle
     }
     else
     {
-        RETURN_IF_HIP_ERROR(hipMemcpyAsync(nnz_total_dev_host_ptr,
-                                           &csr_row_ptr[m],
-                                           sizeof(rocsparse_int),
-                                           hipMemcpyDeviceToHost,
-                                           stream));
+        rocsparse_int start, end;
+        RETURN_IF_HIP_ERROR(hipMemcpyAsync(
+            &start, &csr_row_ptr[0], sizeof(rocsparse_int), hipMemcpyDeviceToHost, handle->stream));
+        RETURN_IF_HIP_ERROR(hipMemcpyAsync(
+            &end, &csr_row_ptr[m], sizeof(rocsparse_int), hipMemcpyDeviceToHost, handle->stream));
+        RETURN_IF_HIP_ERROR(hipStreamSynchronize(handle->stream));
 
-        *nnz_total_dev_host_ptr -= descr->base;
+        *nnz_total_dev_host_ptr = end - start;
     }
 
     return rocsparse_status_success;
