@@ -198,7 +198,7 @@ __device__ void
                     table[col_D - chunk_begin] = 1;
 
                     // Atomically accumulate the entry of D
-                    // atomicAdd(&data[col_D - chunk_begin], beta * csr_val_D[j]);
+                    // rocsparse_atomic_add(&data[col_D - chunk_begin], beta * csr_val_D[j]);
                 }
                 else if(col_D >= chunk_end)
                 {
@@ -220,7 +220,7 @@ __device__ void
         {
             // Atomically determine the new chunks beginning (minimum column index of B
             // that is larger than the current chunks end point)
-            atomicMin(&next_chunk, min_col);
+            rocsparse_atomic_min(&next_chunk, min_col);
         }
 
         // Wait for all threads to finish
@@ -574,7 +574,7 @@ static __device__ __forceinline__ bool insert_key(I key, I* __restrict__ table,
         else if(table[hash] == empty)
         {
             // If empty, add element with atomic
-            if(atomicCAS(&table[hash], empty, key) == empty)
+            if(rocsparse_atomic_cas(&table[hash], empty, key) == empty)
             {
                 // Increment number of insertions
                 return true;
