@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2022 Advanced Micro Devices, Inc.
+ * Copyright (C) 2022-2023 Advanced Micro Devices, Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -320,7 +320,7 @@ __launch_bounds__(BLOCKSIZE) __global__
             iter = sdata2[0];
             if(hipThreadIdx_x == 0)
             {
-                atomicMax(niter__, iter + 1);
+                rocsparse_atomic_max(niter__, iter + 1);
             }
         }
     }
@@ -329,14 +329,14 @@ __launch_bounds__(BLOCKSIZE) __global__
     {
         if(hipThreadIdx_x == 0)
         {
-            atomicMax(nrms_corr, nrminf);
+            rocsparse_atomic_max(nrms_corr, nrminf);
         }
     }
     if(compute_nrm_residual)
     {
         if(hipThreadIdx_x == 0)
         {
-            atomicMax(nrms_residual, nrminf_residual);
+            rocsparse_atomic_max(nrms_residual, nrminf_residual);
         }
     }
 }
@@ -653,6 +653,10 @@ struct rocsparse_csritilu0x_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
                     return rocsparse_status_internal_error;
                 }
             }
+
+            //
+            // No stream synchronization needed here,
+            //
             return rocsparse_status_success;
         }
     };
@@ -1051,6 +1055,8 @@ struct rocsparse_csritilu0x_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
                                            handle_->stream);
                         }
 
+                        RETURN_IF_HIP_ERROR(hipStreamSynchronize(handle_->stream));
+
                         if(compute_nrm_residual && compute_nrm_corr)
                         {
                             nrm_indicator = std::max(nrm_residual, nrm_corr);
@@ -1143,7 +1149,9 @@ struct rocsparse_csritilu0x_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
                     nrm_indicator_previous = nrm_indicator;
                 }
             }
+
             RETURN_IF_HIP_ERROR(on_device(p_iter, (converged) ? nmaxiter_ : (&nmaxiter), stream));
+            RETURN_IF_HIP_ERROR(hipStreamSynchronize(stream));
             return rocsparse_status_success;
         }
     };
